# 发布插件到插件市场

在编写完插件后，你可以选择将插件发布到 AstrBot 的插件市场，让更多用户使用你的插件。

AstrBot 使用 GitHub 托管插件，因此你需要先将插件代码推送到之前创建的 GitHub 插件仓库中。

你可以前往 [AstrBot 插件市场](https://plugins.astrbot.app) 提交你的插件。进入该网站后，点击右下角的 `+` 按钮，填写好基本信息、作者信息、仓库信息等内容后，点击 `提交到 GTIHUB` 按钮，你将会被导航到 AstrBot 仓库的 Issue 提交页面，请确认信息无误后点击 `Create` 按钮提交，即可完成插件发布。

![fill out the form](https://files.astrbot.app/docs/source/images/plugin-publish/image.png)
